summaryrefslogtreecommitdiff
path: root/actions/twitapisearchatom.php
diff options
context:
space:
mode:
Diffstat (limited to 'actions/twitapisearchatom.php')
-rw-r--r--actions/twitapisearchatom.php20
1 files changed, 10 insertions, 10 deletions
diff --git a/actions/twitapisearchatom.php b/actions/twitapisearchatom.php
index 3678213c3..2f587d604 100644
--- a/actions/twitapisearchatom.php
+++ b/actions/twitapisearchatom.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Action for showing Twitter-like Atom search results
*
@@ -20,14 +20,14 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Search
- * @package Laconica
- * @author Zach Copley <zach@controlyourself.ca>
- * @copyright 2008-2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
+ * @copyright 2008-2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -41,10 +41,10 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
* RSS10Action.
*
* @category Search
- * @package Laconica
- * @author Zach Copley <zach@controlyourself.ca>
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*
* @see TwitterapiAction
*/
@@ -227,7 +227,7 @@ class TwitapisearchatomAction extends TwitterapiAction
$server = common_config('site', 'server');
$sitename = common_config('site', 'name');
// XXX: Use xmlns:laconica instead?
$this->elementStart('feed',
array('xmlns' => 'http://www.w3.org/2005/Atom',
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Action for showing Twitter-like Atom search results
@@ -227,7 +227,7 @@ class TwitapisearchatomAction extends TwitterapiAction
$server = common_config('site', 'server');
$sitename = common_config('site', 'name');
- // XXX: Use xmlns:laconica instead?
+ // XXX: Use xmlns:statusnet instead?
$this->elementStart('feed',
array('xmlns' => 'http://www.w3.org/2005/Atom',